# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class LocationAddress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        LocationAddress - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'city': 'str',
            'country': 'str',
            'country_name': 'str',
            'state': 'str',
            'street1': 'str',
            'street2': 'str',
            'zipcode': 'str'
        }

        self.attribute_map = {
            'city': 'city',
            'country': 'country',
            'country_name': 'countryName',
            'state': 'state',
            'street1': 'street1',
            'street2': 'street2',
            'zipcode': 'zipcode'
        }

        self._city = None
        self._country = None
        self._country_name = None
        self._state = None
        self._street1 = None
        self._street2 = None
        self._zipcode = None

    @property
    def city(self):
        """
        Gets the city of this LocationAddress.


        :return: The city of this LocationAddress.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """
        Sets the city of this LocationAddress.


        :param city: The city of this LocationAddress.
        :type: str
        """
        
        self._city = city

    @property
    def country(self):
        """
        Gets the country of this LocationAddress.


        :return: The country of this LocationAddress.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this LocationAddress.


        :param country: The country of this LocationAddress.
        :type: str
        """
        
        self._country = country

    @property
    def country_name(self):
        """
        Gets the country_name of this LocationAddress.


        :return: The country_name of this LocationAddress.
        :rtype: str
        """
        return self._country_name

    @country_name.setter
    def country_name(self, country_name):
        """
        Sets the country_name of this LocationAddress.


        :param country_name: The country_name of this LocationAddress.
        :type: str
        """
        
        self._country_name = country_name

    @property
    def state(self):
        """
        Gets the state of this LocationAddress.


        :return: The state of this LocationAddress.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this LocationAddress.


        :param state: The state of this LocationAddress.
        :type: str
        """
        
        self._state = state

    @property
    def street1(self):
        """
        Gets the street1 of this LocationAddress.


        :return: The street1 of this LocationAddress.
        :rtype: str
        """
        return self._street1

    @street1.setter
    def street1(self, street1):
        """
        Sets the street1 of this LocationAddress.


        :param street1: The street1 of this LocationAddress.
        :type: str
        """
        
        self._street1 = street1

    @property
    def street2(self):
        """
        Gets the street2 of this LocationAddress.


        :return: The street2 of this LocationAddress.
        :rtype: str
        """
        return self._street2

    @street2.setter
    def street2(self, street2):
        """
        Sets the street2 of this LocationAddress.


        :param street2: The street2 of this LocationAddress.
        :type: str
        """
        
        self._street2 = street2

    @property
    def zipcode(self):
        """
        Gets the zipcode of this LocationAddress.


        :return: The zipcode of this LocationAddress.
        :rtype: str
        """
        return self._zipcode

    @zipcode.setter
    def zipcode(self, zipcode):
        """
        Sets the zipcode of this LocationAddress.


        :param zipcode: The zipcode of this LocationAddress.
        :type: str
        """
        
        self._zipcode = zipcode

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class RoutingData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        RoutingData - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'queue_id': 'str',
            'language_id': 'str',
            'priority': 'int',
            'skill_ids': 'list[str]',
            'preferred_agent_ids': 'list[str]'
        }

        self.attribute_map = {
            'queue_id': 'queueId',
            'language_id': 'languageId',
            'priority': 'priority',
            'skill_ids': 'skillIds',
            'preferred_agent_ids': 'preferredAgentIds'
        }

        self._queue_id = None
        self._language_id = None
        self._priority = None
        self._skill_ids = None
        self._preferred_agent_ids = None

    @property
    def queue_id(self):
        """
        Gets the queue_id of this RoutingData.
        The identifier of the routing queue

        :return: The queue_id of this RoutingData.
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """
        Sets the queue_id of this RoutingData.
        The identifier of the routing queue

        :param queue_id: The queue_id of this RoutingData.
        :type: str
        """
        
        self._queue_id = queue_id

    @property
    def language_id(self):
        """
        Gets the language_id of this RoutingData.
        The identifier of a language to be considered in routing

        :return: The language_id of this RoutingData.
        :rtype: str
        """
        return self._language_id

    @language_id.setter
    def language_id(self, language_id):
        """
        Sets the language_id of this RoutingData.
        The identifier of a language to be considered in routing

        :param language_id: The language_id of this RoutingData.
        :type: str
        """
        
        self._language_id = language_id

    @property
    def priority(self):
        """
        Gets the priority of this RoutingData.
        The priority for routing

        :return: The priority of this RoutingData.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this RoutingData.
        The priority for routing

        :param priority: The priority of this RoutingData.
        :type: int
        """
        
        self._priority = priority

    @property
    def skill_ids(self):
        """
        Gets the skill_ids of this RoutingData.
        A list of skill identifiers to be considered in routing

        :return: The skill_ids of this RoutingData.
        :rtype: list[str]
        """
        return self._skill_ids

    @skill_ids.setter
    def skill_ids(self, skill_ids):
        """
        Sets the skill_ids of this RoutingData.
        A list of skill identifiers to be considered in routing

        :param skill_ids: The skill_ids of this RoutingData.
        :type: list[str]
        """
        
        self._skill_ids = skill_ids

    @property
    def preferred_agent_ids(self):
        """
        Gets the preferred_agent_ids of this RoutingData.
        A list of agents to be preferred in routing

        :return: The preferred_agent_ids of this RoutingData.
        :rtype: list[str]
        """
        return self._preferred_agent_ids

    @preferred_agent_ids.setter
    def preferred_agent_ids(self, preferred_agent_ids):
        """
        Sets the preferred_agent_ids of this RoutingData.
        A list of agents to be preferred in routing

        :param preferred_agent_ids: The preferred_agent_ids of this RoutingData.
        :type: list[str]
        """
        
        self._preferred_agent_ids = preferred_agent_ids

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.configuration_api import ConfigurationApi


class TestConfigurationApi(unittest.TestCase):
    """ ConfigurationApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.configuration_api.ConfigurationApi()

    def tearDown(self):
        pass

    def test_get_recordingkeys(self):
        """
        Test case for get_recordingkeys

        Get encryption key list
        """
        pass

    def test_get_recordingkeys_rotationschedule(self):
        """
        Test case for get_recordingkeys_rotationschedule

        Get key rotation schedule
        """
        pass

    def test_post_recordingkeys(self):
        """
        Test case for post_recordingkeys

        Create encryption key
        """
        pass

    def test_put_recordingkeys_rotationschedule(self):
        """
        Test case for put_recordingkeys_rotationschedule

        Update key rotation schedule
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.groups_api import GroupsApi


class TestGroupsApi(unittest.TestCase):
    """ GroupsApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.groups_api.GroupsApi()

    def tearDown(self):
        pass

    def test_delete_group_id_members(self):
        """
        Test case for delete_group_id_members

        Remove members
        """
        pass

    def test_get_group_id(self):
        """
        Test case for get_group_id

        Get group
        """
        pass

    def test_get_group_id_members(self):
        """
        Test case for get_group_id_members

        Get group members
        """
        pass

    def test_get_groups(self):
        """
        Test case for get_groups

        Get a group list
        """
        pass

    def test_get_search(self):
        """
        Test case for get_search

        Search using q64
        """
        pass

    def test_post_group_id_members(self):
        """
        Test case for post_group_id_members

        Add members
        """
        pass

    def test_post_groups(self):
        """
        Test case for post_groups

        Create a group
        """
        pass

    def test_post_search(self):
        """
        Test case for post_search

        Search
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.identity_provider_api import IdentityProviderApi


class TestIdentityProviderApi(unittest.TestCase):
    """ IdentityProviderApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.identity_provider_api.IdentityProviderApi()

    def tearDown(self):
        pass

    def test_delete_adfs(self):
        """
        Test case for delete_adfs

        Delete ADFS Identity Provider
        """
        pass

    def test_delete_cic(self):
        """
        Test case for delete_cic

        Delete Customer Interaction Center (CIC) Identity Provider
        """
        pass

    def test_delete_okta(self):
        """
        Test case for delete_okta

        Delete Okta Identity Provider
        """
        pass

    def test_delete_onelogin(self):
        """
        Test case for delete_onelogin

        Delete OneLogin Identity Provider
        """
        pass

    def test_delete_provider_id(self):
        """
        Test case for delete_provider_id

        Delete an identity provider
        """
        pass

    def test_delete_purecloud(self):
        """
        Test case for delete_purecloud

        Delete PureCloud Identity Provider
        """
        pass

    def test_delete_salesforce(self):
        """
        Test case for delete_salesforce

        Delete Salesforce Identity Provider
        """
        pass

    def test_get_adfs(self):
        """
        Test case for get_adfs

        Get ADFS Identity Provider
        """
        pass

    def test_get_cic(self):
        """
        Test case for get_cic

        Get Customer Interaction Center (CIC) Identity Provider
        """
        pass

    def test_get_identityproviders(self):
        """
        Test case for get_identityproviders

        The list of identity providers
        """
        pass

    def test_get_okta(self):
        """
        Test case for get_okta

        Get Okta Identity Provider
        """
        pass

    def test_get_onelogin(self):
        """
        Test case for get_onelogin

        Get OneLogin Identity Provider
        """
        pass

    def test_get_provider_id(self):
        """
        Test case for get_provider_id

        Get an identity provider
        """
        pass

    def test_get_purecloud(self):
        """
        Test case for get_purecloud

        Get PureCloud Identity Provider
        """
        pass

    def test_get_salesforce(self):
        """
        Test case for get_salesforce

        Get Salesforce Identity Provider
        """
        pass

    def test_put_adfs(self):
        """
        Test case for put_adfs

        Update/Create ADFS Identity Provider
        """
        pass

    def test_put_cic(self):
        """
        Test case for put_cic

        Update/Create Customer Interaction Center (CIC) Identity Provider
        """
        pass

    def test_put_okta(self):
        """
        Test case for put_okta

        Update/Create Okta Identity Provider
        """
        pass

    def test_put_onelogin(self):
        """
        Test case for put_onelogin

        Update/Create OneLogin Identity Provider
        """
        pass

    def test_put_provider_id(self):
        """
        Test case for put_provider_id

        Update an identity provider
        """
        pass

    def test_put_purecloud(self):
        """
        Test case for put_purecloud

        Update/Create PureCloud Identity Provider
        """
        pass

    def test_put_salesforce(self):
        """
        Test case for put_salesforce

        Update/Create Salesforce Identity Provider
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class PolicyConditions(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PolicyConditions - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'for_users': 'list[User]',
            'directions': 'list[str]',
            'date_ranges': 'list[str]',
            'media_types': 'list[str]',
            'for_queues': 'list[Queue]',
            'duration': 'DurationCondition',
            'wrapup_codes': 'list[WrapupCode]',
            'time_allowed': 'TimeAllowed'
        }

        self.attribute_map = {
            'for_users': 'forUsers',
            'directions': 'directions',
            'date_ranges': 'dateRanges',
            'media_types': 'mediaTypes',
            'for_queues': 'forQueues',
            'duration': 'duration',
            'wrapup_codes': 'wrapupCodes',
            'time_allowed': 'timeAllowed'
        }

        self._for_users = None
        self._directions = None
        self._date_ranges = None
        self._media_types = None
        self._for_queues = None
        self._duration = None
        self._wrapup_codes = None
        self._time_allowed = None

    @property
    def for_users(self):
        """
        Gets the for_users of this PolicyConditions.


        :return: The for_users of this PolicyConditions.
        :rtype: list[User]
        """
        return self._for_users

    @for_users.setter
    def for_users(self, for_users):
        """
        Sets the for_users of this PolicyConditions.


        :param for_users: The for_users of this PolicyConditions.
        :type: list[User]
        """
        
        self._for_users = for_users

    @property
    def directions(self):
        """
        Gets the directions of this PolicyConditions.


        :return: The directions of this PolicyConditions.
        :rtype: list[str]
        """
        return self._directions

    @directions.setter
    def directions(self, directions):
        """
        Sets the directions of this PolicyConditions.


        :param directions: The directions of this PolicyConditions.
        :type: list[str]
        """
        
        self._directions = directions

    @property
    def date_ranges(self):
        """
        Gets the date_ranges of this PolicyConditions.


        :return: The date_ranges of this PolicyConditions.
        :rtype: list[str]
        """
        return self._date_ranges

    @date_ranges.setter
    def date_ranges(self, date_ranges):
        """
        Sets the date_ranges of this PolicyConditions.


        :param date_ranges: The date_ranges of this PolicyConditions.
        :type: list[str]
        """
        
        self._date_ranges = date_ranges

    @property
    def media_types(self):
        """
        Gets the media_types of this PolicyConditions.


        :return: The media_types of this PolicyConditions.
        :rtype: list[str]
        """
        return self._media_types

    @media_types.setter
    def media_types(self, media_types):
        """
        Sets the media_types of this PolicyConditions.


        :param media_types: The media_types of this PolicyConditions.
        :type: list[str]
        """
        
        self._media_types = media_types

    @property
    def for_queues(self):
        """
        Gets the for_queues of this PolicyConditions.


        :return: The for_queues of this PolicyConditions.
        :rtype: list[Queue]
        """
        return self._for_queues

    @for_queues.setter
    def for_queues(self, for_queues):
        """
        Sets the for_queues of this PolicyConditions.


        :param for_queues: The for_queues of this PolicyConditions.
        :type: list[Queue]
        """
        
        self._for_queues = for_queues

    @property
    def duration(self):
        """
        Gets the duration of this PolicyConditions.


        :return: The duration of this PolicyConditions.
        :rtype: DurationCondition
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """
        Sets the duration of this PolicyConditions.


        :param duration: The duration of this PolicyConditions.
        :type: DurationCondition
        """
        
        self._duration = duration

    @property
    def wrapup_codes(self):
        """
        Gets the wrapup_codes of this PolicyConditions.


        :return: The wrapup_codes of this PolicyConditions.
        :rtype: list[WrapupCode]
        """
        return self._wrapup_codes

    @wrapup_codes.setter
    def wrapup_codes(self, wrapup_codes):
        """
        Sets the wrapup_codes of this PolicyConditions.


        :param wrapup_codes: The wrapup_codes of this PolicyConditions.
        :type: list[WrapupCode]
        """
        
        self._wrapup_codes = wrapup_codes

    @property
    def time_allowed(self):
        """
        Gets the time_allowed of this PolicyConditions.


        :return: The time_allowed of this PolicyConditions.
        :rtype: TimeAllowed
        """
        return self._time_allowed

    @time_allowed.setter
    def time_allowed(self, time_allowed):
        """
        Sets the time_allowed of this PolicyConditions.


        :param time_allowed: The time_allowed of this PolicyConditions.
        :type: TimeAllowed
        """
        
        self._time_allowed = time_allowed

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.response_management_api import ResponseManagementApi


class TestResponseManagementApi(unittest.TestCase):
    """ ResponseManagementApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.response_management_api.ResponseManagementApi()

    def tearDown(self):
        pass

    def test_delete_libraries_library_id(self):
        """
        Test case for delete_libraries_library_id

        Delete an existing response library.
        """
        pass

    def test_delete_responses_response_id(self):
        """
        Test case for delete_responses_response_id

        Delete an existing response.
        """
        pass

    def test_get_libraries(self):
        """
        Test case for get_libraries

        Gets a list of existing response libraries.
        """
        pass

    def test_get_libraries_library_id(self):
        """
        Test case for get_libraries_library_id

        Get details about an existing response library.
        """
        pass

    def test_get_responses(self):
        """
        Test case for get_responses

        Gets a list of existing responses.
        """
        pass

    def test_get_responses_response_id(self):
        """
        Test case for get_responses_response_id

        Get details about an existing response.
        """
        pass

    def test_post_libraries(self):
        """
        Test case for post_libraries

        Create a response library.
        """
        pass

    def test_post_responses(self):
        """
        Test case for post_responses

        Create a response.
        """
        pass

    def test_post_responses_query(self):
        """
        Test case for post_responses_query

        Query responses
        """
        pass

    def test_put_libraries_library_id(self):
        """
        Test case for put_libraries_library_id

        Update an existing response library.
        """
        pass

    def test_put_responses_response_id(self):
        """
        Test case for put_responses_response_id

        Update an existing response.
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class InteractionStatsAlert(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        InteractionStatsAlert - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'dimension': 'str',
            'dimension_value': 'str',
            'metric': 'str',
            'media_type': 'str',
            'numeric_range': 'str',
            'statistic': 'str',
            'value': 'float',
            'rule_id': 'str',
            'unread': 'bool',
            'start_date': 'datetime',
            'end_date': 'datetime',
            'notification_users': 'list[User]',
            'alert_types': 'list[str]',
            'rule_uri': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'dimension': 'dimension',
            'dimension_value': 'dimensionValue',
            'metric': 'metric',
            'media_type': 'mediaType',
            'numeric_range': 'numericRange',
            'statistic': 'statistic',
            'value': 'value',
            'rule_id': 'ruleId',
            'unread': 'unread',
            'start_date': 'startDate',
            'end_date': 'endDate',
            'notification_users': 'notificationUsers',
            'alert_types': 'alertTypes',
            'rule_uri': 'ruleUri',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._dimension = None
        self._dimension_value = None
        self._metric = None
        self._media_type = None
        self._numeric_range = None
        self._statistic = None
        self._value = None
        self._rule_id = None
        self._unread = False
        self._start_date = None
        self._end_date = None
        self._notification_users = None
        self._alert_types = None
        self._rule_uri = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this InteractionStatsAlert.
        The globally unique identifier for the object.

        :return: The id of this InteractionStatsAlert.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this InteractionStatsAlert.
        The globally unique identifier for the object.

        :param id: The id of this InteractionStatsAlert.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this InteractionStatsAlert.
        Name of the rule that generated the alert

        :return: The name of this InteractionStatsAlert.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this InteractionStatsAlert.
        Name of the rule that generated the alert

        :param name: The name of this InteractionStatsAlert.
        :type: str
        """
        
        self._name = name

    @property
    def dimension(self):
        """
        Gets the dimension of this InteractionStatsAlert.
        The dimension of concern.

        :return: The dimension of this InteractionStatsAlert.
        :rtype: str
        """
        return self._dimension

    @dimension.setter
    def dimension(self, dimension):
        """
        Sets the dimension of this InteractionStatsAlert.
        The dimension of concern.

        :param dimension: The dimension of this InteractionStatsAlert.
        :type: str
        """
        allowed_values = ["queueId", "userId"]
        if dimension not in allowed_values:
            raise ValueError(
                "Invalid value for `dimension`, must be one of {0}"
                .format(allowed_values)
            )

        self._dimension = dimension

    @property
    def dimension_value(self):
        """
        Gets the dimension_value of this InteractionStatsAlert.
        The value of the dimension.

        :return: The dimension_value of this InteractionStatsAlert.
        :rtype: str
        """
        return self._dimension_value

    @dimension_value.setter
    def dimension_value(self, dimension_value):
        """
        Sets the dimension_value of this InteractionStatsAlert.
        The value of the dimension.

        :param dimension_value: The dimension_value of this InteractionStatsAlert.
        :type: str
        """
        
        self._dimension_value = dimension_value

    @property
    def metric(self):
        """
        Gets the metric of this InteractionStatsAlert.
        The metric to be assessed.

        :return: The metric of this InteractionStatsAlert.
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """
        Sets the metric of this InteractionStatsAlert.
        The metric to be assessed.

        :param metric: The metric of this InteractionStatsAlert.
        :type: str
        """
        allowed_values = ["tAbandon", "tAnswered", "tTalk", "nOffered", "tHandle", "nTransferred", "oServiceLevel", "tWait", "tHeld", "tAcw"]
        if metric not in allowed_values:
            raise ValueError(
                "Invalid value for `metric`, must be one of {0}"
                .format(allowed_values)
            )

        self._metric = metric

    @property
    def media_type(self):
        """
        Gets the media_type of this InteractionStatsAlert.
        The media type.

        :return: The media_type of this InteractionStatsAlert.
        :rtype: str
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """
        Sets the media_type of this InteractionStatsAlert.
        The media type.

        :param media_type: The media_type of this InteractionStatsAlert.
        :type: str
        """
        allowed_values = ["voice", "chat", "email"]
        if media_type not in allowed_values:
            raise ValueError(
                "Invalid value for `media_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._media_type = media_type

    @property
    def numeric_range(self):
        """
        Gets the numeric_range of this InteractionStatsAlert.
        The comparison descriptor used against the metric's value.

        :return: The numeric_range of this InteractionStatsAlert.
        :rtype: str
        """
        return self._numeric_range

    @numeric_range.setter
    def numeric_range(self, numeric_range):
        """
        Sets the numeric_range of this InteractionStatsAlert.
        The comparison descriptor used against the metric's value.

        :param numeric_range: The numeric_range of this InteractionStatsAlert.
        :type: str
        """
        allowed_values = ["gt", "gte", "lt", "lte", "eq", "ne"]
        if numeric_range not in allowed_values:
            raise ValueError(
                "Invalid value for `numeric_range`, must be one of {0}"
                .format(allowed_values)
            )

        self._numeric_range = numeric_range

    @property
    def statistic(self):
        """
        Gets the statistic of this InteractionStatsAlert.
        The statistic of concern for the metric.

        :return: The statistic of this InteractionStatsAlert.
        :rtype: str
        """
        return self._statistic

    @statistic.setter
    def statistic(self, statistic):
        """
        Sets the statistic of this InteractionStatsAlert.
        The statistic of concern for the metric.

        :param statistic: The statistic of this InteractionStatsAlert.
        :type: str
        """
        allowed_values = ["count", "min", "ratio", "max"]
        if statistic not in allowed_values:
            raise ValueError(
                "Invalid value for `statistic`, must be one of {0}"
                .format(allowed_values)
            )

        self._statistic = statistic

    @property
    def value(self):
        """
        Gets the value of this InteractionStatsAlert.
        The threshold value.

        :return: The value of this InteractionStatsAlert.
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this InteractionStatsAlert.
        The threshold value.

        :param value: The value of this InteractionStatsAlert.
        :type: float
        """
        
        self._value = value

    @property
    def rule_id(self):
        """
        Gets the rule_id of this InteractionStatsAlert.
        The id of the rule.

        :return: The rule_id of this InteractionStatsAlert.
        :rtype: str
        """
        return self._rule_id

    @rule_id.setter
    def rule_id(self, rule_id):
        """
        Sets the rule_id of this InteractionStatsAlert.
        The id of the rule.

        :param rule_id: The rule_id of this InteractionStatsAlert.
        :type: str
        """
        
        self._rule_id = rule_id

    @property
    def unread(self):
        """
        Gets the unread of this InteractionStatsAlert.
        Indicates if the alert has been read.

        :return: The unread of this InteractionStatsAlert.
        :rtype: bool
        """
        return self._unread

    @unread.setter
    def unread(self, unread):
        """
        Sets the unread of this InteractionStatsAlert.
        Indicates if the alert has been read.

        :param unread: The unread of this InteractionStatsAlert.
        :type: bool
        """
        
        self._unread = unread

    @property
    def start_date(self):
        """
        Gets the start_date of this InteractionStatsAlert.
        The date/time the alert was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The start_date of this InteractionStatsAlert.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this InteractionStatsAlert.
        The date/time the alert was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param start_date: The start_date of this InteractionStatsAlert.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this InteractionStatsAlert.
        The date/time the owning rule exiting in alarm status. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The end_date of this InteractionStatsAlert.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this InteractionStatsAlert.
        The date/time the owning rule exiting in alarm status. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param end_date: The end_date of this InteractionStatsAlert.
        :type: datetime
        """
        
        self._end_date = end_date

    @property
    def notification_users(self):
        """
        Gets the notification_users of this InteractionStatsAlert.
        The ids of users who were notified of alarm state change.

        :return: The notification_users of this InteractionStatsAlert.
        :rtype: list[User]
        """
        return self._notification_users

    @notification_users.setter
    def notification_users(self, notification_users):
        """
        Sets the notification_users of this InteractionStatsAlert.
        The ids of users who were notified of alarm state change.

        :param notification_users: The notification_users of this InteractionStatsAlert.
        :type: list[User]
        """
        
        self._notification_users = notification_users

    @property
    def alert_types(self):
        """
        Gets the alert_types of this InteractionStatsAlert.
        A collection of notification methods. = ['SMS', 'DEVICE', 'EMAIL']

        :return: The alert_types of this InteractionStatsAlert.
        :rtype: list[str]
        """
        return self._alert_types

    @alert_types.setter
    def alert_types(self, alert_types):
        """
        Sets the alert_types of this InteractionStatsAlert.
        A collection of notification methods. = ['SMS', 'DEVICE', 'EMAIL']

        :param alert_types: The alert_types of this InteractionStatsAlert.
        :type: list[str]
        """
        
        self._alert_types = alert_types

    @property
    def rule_uri(self):
        """
        Gets the rule_uri of this InteractionStatsAlert.


        :return: The rule_uri of this InteractionStatsAlert.
        :rtype: str
        """
        return self._rule_uri

    @rule_uri.setter
    def rule_uri(self, rule_uri):
        """
        Sets the rule_uri of this InteractionStatsAlert.


        :param rule_uri: The rule_uri of this InteractionStatsAlert.
        :type: str
        """
        
        self._rule_uri = rule_uri

    @property
    def self_uri(self):
        """
        Gets the self_uri of this InteractionStatsAlert.
        The URI for this object

        :return: The self_uri of this InteractionStatsAlert.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this InteractionStatsAlert.
        The URI for this object

        :param self_uri: The self_uri of this InteractionStatsAlert.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Keyword(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Keyword - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'phrase': 'str',
            'confidence': 'int',
            'agent_score_modifier': 'int',
            'customer_score_modifier': 'int',
            'alternate_spellings': 'list[str]'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'phrase': 'phrase',
            'confidence': 'confidence',
            'agent_score_modifier': 'agentScoreModifier',
            'customer_score_modifier': 'customerScoreModifier',
            'alternate_spellings': 'alternateSpellings'
        }

        self._id = None
        self._name = None
        self._phrase = None
        self._confidence = None
        self._agent_score_modifier = None
        self._customer_score_modifier = None
        self._alternate_spellings = None

    @property
    def id(self):
        """
        Gets the id of this Keyword.


        :return: The id of this Keyword.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Keyword.


        :param id: The id of this Keyword.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Keyword.


        :return: The name of this Keyword.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Keyword.


        :param name: The name of this Keyword.
        :type: str
        """
        
        self._name = name

    @property
    def phrase(self):
        """
        Gets the phrase of this Keyword.


        :return: The phrase of this Keyword.
        :rtype: str
        """
        return self._phrase

    @phrase.setter
    def phrase(self, phrase):
        """
        Sets the phrase of this Keyword.


        :param phrase: The phrase of this Keyword.
        :type: str
        """
        
        self._phrase = phrase

    @property
    def confidence(self):
        """
        Gets the confidence of this Keyword.


        :return: The confidence of this Keyword.
        :rtype: int
        """
        return self._confidence

    @confidence.setter
    def confidence(self, confidence):
        """
        Sets the confidence of this Keyword.


        :param confidence: The confidence of this Keyword.
        :type: int
        """
        
        self._confidence = confidence

    @property
    def agent_score_modifier(self):
        """
        Gets the agent_score_modifier of this Keyword.


        :return: The agent_score_modifier of this Keyword.
        :rtype: int
        """
        return self._agent_score_modifier

    @agent_score_modifier.setter
    def agent_score_modifier(self, agent_score_modifier):
        """
        Sets the agent_score_modifier of this Keyword.


        :param agent_score_modifier: The agent_score_modifier of this Keyword.
        :type: int
        """
        
        self._agent_score_modifier = agent_score_modifier

    @property
    def customer_score_modifier(self):
        """
        Gets the customer_score_modifier of this Keyword.


        :return: The customer_score_modifier of this Keyword.
        :rtype: int
        """
        return self._customer_score_modifier

    @customer_score_modifier.setter
    def customer_score_modifier(self, customer_score_modifier):
        """
        Sets the customer_score_modifier of this Keyword.


        :param customer_score_modifier: The customer_score_modifier of this Keyword.
        :type: int
        """
        
        self._customer_score_modifier = customer_score_modifier

    @property
    def alternate_spellings(self):
        """
        Gets the alternate_spellings of this Keyword.


        :return: The alternate_spellings of this Keyword.
        :rtype: list[str]
        """
        return self._alternate_spellings

    @alternate_spellings.setter
    def alternate_spellings(self, alternate_spellings):
        """
        Sets the alternate_spellings of this Keyword.


        :param alternate_spellings: The alternate_spellings of this Keyword.
        :type: list[str]
        """
        
        self._alternate_spellings = alternate_spellings

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class EdgeLogsJobFile(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EdgeLogsJobFile - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'time_created': 'datetime',
            'time_modified': 'datetime',
            'size_bytes': 'float',
            'upload_status': 'str',
            'edge_path': 'str',
            'download_id': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'time_created': 'timeCreated',
            'time_modified': 'timeModified',
            'size_bytes': 'sizeBytes',
            'upload_status': 'uploadStatus',
            'edge_path': 'edgePath',
            'download_id': 'downloadId',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._time_created = None
        self._time_modified = None
        self._size_bytes = None
        self._upload_status = None
        self._edge_path = None
        self._download_id = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this EdgeLogsJobFile.
        The globally unique identifier for the object.

        :return: The id of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this EdgeLogsJobFile.
        The globally unique identifier for the object.

        :param id: The id of this EdgeLogsJobFile.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this EdgeLogsJobFile.


        :return: The name of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EdgeLogsJobFile.


        :param name: The name of this EdgeLogsJobFile.
        :type: str
        """
        
        self._name = name

    @property
    def time_created(self):
        """
        Gets the time_created of this EdgeLogsJobFile.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The time_created of this EdgeLogsJobFile.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this EdgeLogsJobFile.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param time_created: The time_created of this EdgeLogsJobFile.
        :type: datetime
        """
        
        self._time_created = time_created

    @property
    def time_modified(self):
        """
        Gets the time_modified of this EdgeLogsJobFile.
        The time this log file was last modified on the Edge. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The time_modified of this EdgeLogsJobFile.
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """
        Sets the time_modified of this EdgeLogsJobFile.
        The time this log file was last modified on the Edge. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param time_modified: The time_modified of this EdgeLogsJobFile.
        :type: datetime
        """
        
        self._time_modified = time_modified

    @property
    def size_bytes(self):
        """
        Gets the size_bytes of this EdgeLogsJobFile.
        The size of this file in bytes.

        :return: The size_bytes of this EdgeLogsJobFile.
        :rtype: float
        """
        return self._size_bytes

    @size_bytes.setter
    def size_bytes(self, size_bytes):
        """
        Sets the size_bytes of this EdgeLogsJobFile.
        The size of this file in bytes.

        :param size_bytes: The size_bytes of this EdgeLogsJobFile.
        :type: float
        """
        
        self._size_bytes = size_bytes

    @property
    def upload_status(self):
        """
        Gets the upload_status of this EdgeLogsJobFile.
        The status of the upload of this file from the Edge to the cloud.  Use /upload to start an upload.

        :return: The upload_status of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._upload_status

    @upload_status.setter
    def upload_status(self, upload_status):
        """
        Sets the upload_status of this EdgeLogsJobFile.
        The status of the upload of this file from the Edge to the cloud.  Use /upload to start an upload.

        :param upload_status: The upload_status of this EdgeLogsJobFile.
        :type: str
        """
        allowed_values = ["UPLOADING", "NOT_UPLOADED", "UPLOADED", "ERROR_ON_UPLOAD"]
        if upload_status not in allowed_values:
            raise ValueError(
                "Invalid value for `upload_status`, must be one of {0}"
                .format(allowed_values)
            )

        self._upload_status = upload_status

    @property
    def edge_path(self):
        """
        Gets the edge_path of this EdgeLogsJobFile.
        The path of this file on the Edge.

        :return: The edge_path of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._edge_path

    @edge_path.setter
    def edge_path(self, edge_path):
        """
        Sets the edge_path of this EdgeLogsJobFile.
        The path of this file on the Edge.

        :param edge_path: The edge_path of this EdgeLogsJobFile.
        :type: str
        """
        
        self._edge_path = edge_path

    @property
    def download_id(self):
        """
        Gets the download_id of this EdgeLogsJobFile.
        The download ID to use with the downloads API.

        :return: The download_id of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._download_id

    @download_id.setter
    def download_id(self, download_id):
        """
        Sets the download_id of this EdgeLogsJobFile.
        The download ID to use with the downloads API.

        :param download_id: The download_id of this EdgeLogsJobFile.
        :type: str
        """
        
        self._download_id = download_id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this EdgeLogsJobFile.
        The URI for this object

        :return: The self_uri of this EdgeLogsJobFile.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this EdgeLogsJobFile.
        The URI for this object

        :param self_uri: The self_uri of this EdgeLogsJobFile.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.content_management_api import ContentManagementApi


class TestContentManagementApi(unittest.TestCase):
    """ ContentManagementApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.content_management_api.ContentManagementApi()

    def tearDown(self):
        pass

    def test_delete_documents_document_id(self):
        """
        Test case for delete_documents_document_id

        Delete a document.
        """
        pass

    def test_delete_shares_share_id(self):
        """
        Test case for delete_shares_share_id

        Deletes an existing share.
        """
        pass

    def test_delete_status_status_id(self):
        """
        Test case for delete_status_status_id

        Cancel the command for this status
        """
        pass

    def test_delete_workspaces_workspace_id(self):
        """
        Test case for delete_workspaces_workspace_id

        Delete a workspace
        """
        pass

    def test_delete_workspaces_workspace_id_members_member_id(self):
        """
        Test case for delete_workspaces_workspace_id_members_member_id

        Delete a member from a workspace
        """
        pass

    def test_delete_workspaces_workspace_id_tagvalues_tag_id(self):
        """
        Test case for delete_workspaces_workspace_id_tagvalues_tag_id

        Delete workspace tag
        """
        pass

    def test_get_documents(self):
        """
        Test case for get_documents

        Get a list of documents.
        """
        pass

    def test_get_documents_document_id(self):
        """
        Test case for get_documents_document_id

        Get a document.
        """
        pass

    def test_get_documents_document_id_audits(self):
        """
        Test case for get_documents_document_id_audits

        Get a list of audits for a document.
        """
        pass

    def test_get_documents_document_id_content(self):
        """
        Test case for get_documents_document_id_content

        Download a document.
        """
        pass

    def test_get_query(self):
        """
        Test case for get_query

        Query content
        """
        pass

    def test_get_securityprofiles(self):
        """
        Test case for get_securityprofiles

        Get a List of Security Profiles
        """
        pass

    def test_get_securityprofiles_securityprofile_id(self):
        """
        Test case for get_securityprofiles_securityprofile_id

        Get a Security Profile
        """
        pass

    def test_get_shared_shared_id(self):
        """
        Test case for get_shared_shared_id

        Get shared documents. Securely download a shared document.
        """
        pass

    def test_get_shares(self):
        """
        Test case for get_shares

        Gets a list of shares.  You must specify at least one filter (e.g. entityId).
        """
        pass

    def test_get_shares_share_id(self):
        """
        Test case for get_shares_share_id

        Retrieve details about an existing share.
        """
        pass

    def test_get_status(self):
        """
        Test case for get_status

        Get a list of statuses for pending operations
        """
        pass

    def test_get_status_status_id(self):
        """
        Test case for get_status_status_id

        Get a status.
        """
        pass

    def test_get_usage(self):
        """
        Test case for get_usage

        Get usage details.
        """
        pass

    def test_get_workspaces(self):
        """
        Test case for get_workspaces

        Get a list of workspaces.
        """
        pass

    def test_get_workspaces_workspace_id(self):
        """
        Test case for get_workspaces_workspace_id

        Get a workspace.
        """
        pass

    def test_get_workspaces_workspace_id_members(self):
        """
        Test case for get_workspaces_workspace_id_members

        Get a list workspace members
        """
        pass

    def test_get_workspaces_workspace_id_members_member_id(self):
        """
        Test case for get_workspaces_workspace_id_members_member_id

        Get a workspace member
        """
        pass

    def test_get_workspaces_workspace_id_tagvalues(self):
        """
        Test case for get_workspaces_workspace_id_tagvalues

        Get a list of workspace tags
        """
        pass

    def test_get_workspaces_workspace_id_tagvalues_tag_id(self):
        """
        Test case for get_workspaces_workspace_id_tagvalues_tag_id

        Get a workspace tag
        """
        pass

    def test_post_auditquery(self):
        """
        Test case for post_auditquery

        Query audits
        """
        pass

    def test_post_documents(self):
        """
        Test case for post_documents

        Add a document.
        """
        pass

    def test_post_documents_document_id(self):
        """
        Test case for post_documents_document_id

        Update a document.
        """
        pass

    def test_post_documents_document_id_content(self):
        """
        Test case for post_documents_document_id_content

        Replace the contents of a document.
        """
        pass

    def test_post_query(self):
        """
        Test case for post_query

        Query content
        """
        pass

    def test_post_shares(self):
        """
        Test case for post_shares

        Creates a new share or updates an existing share if the entity has already been shared
        """
        pass

    def test_post_workspaces(self):
        """
        Test case for post_workspaces

        Create a group workspace
        """
        pass

    def test_post_workspaces_workspace_id_tagvalues(self):
        """
        Test case for post_workspaces_workspace_id_tagvalues

        Create a workspace tag
        """
        pass

    def test_post_workspaces_workspace_id_tagvalues_query(self):
        """
        Test case for post_workspaces_workspace_id_tagvalues_query

        Perform a prefix query on tags in the workspace
        """
        pass

    def test_put_workspaces_workspace_id(self):
        """
        Test case for put_workspaces_workspace_id

        Update a workspace
        """
        pass

    def test_put_workspaces_workspace_id_members_member_id(self):
        """
        Test case for put_workspaces_workspace_id_members_member_id

        Add a member to a workspace
        """
        pass

    def test_put_workspaces_workspace_id_tagvalues_tag_id(self):
        """
        Test case for put_workspaces_workspace_id_tagvalues_tag_id

        Update a workspace tag. Will update all documents with the new tag value.
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.locations_api import LocationsApi


class TestLocationsApi(unittest.TestCase):
    """ LocationsApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.locations_api.LocationsApi()

    def tearDown(self):
        pass

    def test_get_location_id(self):
        """
        Test case for get_location_id

        Get Location by ID.
        """
        pass

    def test_get_locations(self):
        """
        Test case for get_locations

        Get a list of all locations.
        """
        pass

    def test_get_search(self):
        """
        Test case for get_search

        Search using q64
        """
        pass

    def test_post_search(self):
        """
        Test case for post_search

        Search
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class TransferRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TransferRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'user_id': 'str',
            'address': 'str',
            'user_name': 'str',
            'queue_id': 'str',
            'voicemail': 'bool'
        }

        self.attribute_map = {
            'user_id': 'userId',
            'address': 'address',
            'user_name': 'userName',
            'queue_id': 'queueId',
            'voicemail': 'voicemail'
        }

        self._user_id = None
        self._address = None
        self._user_name = None
        self._queue_id = None
        self._voicemail = False

    @property
    def user_id(self):
        """
        Gets the user_id of this TransferRequest.
        The user ID of the transfer target.

        :return: The user_id of this TransferRequest.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this TransferRequest.
        The user ID of the transfer target.

        :param user_id: The user_id of this TransferRequest.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def address(self):
        """
        Gets the address of this TransferRequest.
        The phone number or address of the transfer target.

        :return: The address of this TransferRequest.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this TransferRequest.
        The phone number or address of the transfer target.

        :param address: The address of this TransferRequest.
        :type: str
        """
        
        self._address = address

    @property
    def user_name(self):
        """
        Gets the user_name of this TransferRequest.
        The user name of the transfer target.

        :return: The user_name of this TransferRequest.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this TransferRequest.
        The user name of the transfer target.

        :param user_name: The user_name of this TransferRequest.
        :type: str
        """
        
        self._user_name = user_name

    @property
    def queue_id(self):
        """
        Gets the queue_id of this TransferRequest.
        The queue ID of the transfer target.

        :return: The queue_id of this TransferRequest.
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """
        Sets the queue_id of this TransferRequest.
        The queue ID of the transfer target.

        :param queue_id: The queue_id of this TransferRequest.
        :type: str
        """
        
        self._queue_id = queue_id

    @property
    def voicemail(self):
        """
        Gets the voicemail of this TransferRequest.
        If true, then transfer to the user's voicemail.

        :return: The voicemail of this TransferRequest.
        :rtype: bool
        """
        return self._voicemail

    @voicemail.setter
    def voicemail(self, voicemail):
        """
        Sets the voicemail of this TransferRequest.
        If true, then transfer to the user's voicemail.

        :param voicemail: The voicemail of this TransferRequest.
        :type: bool
        """
        
        self._voicemail = voicemail

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.quality_api import QualityApi


class TestQualityApi(unittest.TestCase):
    """ QualityApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.quality_api.QualityApi()

    def tearDown(self):
        pass

    def test_delete_calibrations_calibration_id(self):
        """
        Test case for delete_calibrations_calibration_id

        Delete a calibration by id.
        """
        pass

    def test_delete_conversations_conversation_id_evaluations_evaluation_id(self):
        """
        Test case for delete_conversations_conversation_id_evaluations_evaluation_id

        Delete an evaluation
        """
        pass

    def test_delete_forms_form_id(self):
        """
        Test case for delete_forms_form_id

        Delete an evaluation form.
        """
        pass

    def test_delete_keywordsets(self):
        """
        Test case for delete_keywordsets

        Delete keyword sets
        """
        pass

    def test_delete_keywordsets_keywordset_id(self):
        """
        Test case for delete_keywordsets_keywordset_id

        Delete a keywordSet by id.
        """
        pass

    def test_get_agents_activity(self):
        """
        Test case for get_agents_activity

        Gets a list of Agent Activities
        """
        pass

    def test_get_calibrations(self):
        """
        Test case for get_calibrations

        Get the list of calibrations
        """
        pass

    def test_get_calibrations_calibration_id(self):
        """
        Test case for get_calibrations_calibration_id

        Get a calibration by id.
        """
        pass

    def test_get_conversations_conversation_id_audits(self):
        """
        Test case for get_conversations_conversation_id_audits

        Get audits for conversation or recording
        """
        pass

    def test_get_conversations_conversation_id_evaluations_evaluation_id(self):
        """
        Test case for get_conversations_conversation_id_evaluations_evaluation_id

        Get an evaluation
        """
        pass

    def test_get_evaluations_query(self):
        """
        Test case for get_evaluations_query

        Queries Evaluations and returns a paged list
        """
        pass

    def test_get_evaluators_activity(self):
        """
        Test case for get_evaluators_activity

        Get an evaluator activity
        """
        pass

    def test_get_forms(self):
        """
        Test case for get_forms

        Get the list of evaluation forms
        """
        pass

    def test_get_forms_form_id(self):
        """
        Test case for get_forms_form_id

        Get an evaluation form
        """
        pass

    def test_get_forms_form_id_versions(self):
        """
        Test case for get_forms_form_id_versions

        Gets all the revisions for a specific evaluation.
        """
        pass

    def test_get_keywordsets(self):
        """
        Test case for get_keywordsets

        Get the list of keyword sets
        """
        pass

    def test_get_keywordsets_keywordset_id(self):
        """
        Test case for get_keywordsets_keywordset_id

        Get a keywordSet by id.
        """
        pass

    def test_get_publishedforms(self):
        """
        Test case for get_publishedforms

        Get the published evaluation forms.
        """
        pass

    def test_get_publishedforms_form_id(self):
        """
        Test case for get_publishedforms_form_id

        Get the published evaluation forms.
        """
        pass

    def test_post_calibrations(self):
        """
        Test case for post_calibrations

        Create a calibration
        """
        pass

    def test_post_conversations_conversation_id_evaluations(self):
        """
        Test case for post_conversations_conversation_id_evaluations

        Create an evaluation
        """
        pass

    def test_post_evaluations_aggregates_query(self):
        """
        Test case for post_evaluations_aggregates_query

        Query for evaluation aggregates
        """
        pass

    def test_post_evaluations_scoring(self):
        """
        Test case for post_evaluations_scoring

        Score evaluation
        """
        pass

    def test_post_forms(self):
        """
        Test case for post_forms

        Create an evaluation form.
        """
        pass

    def test_post_keywordsets(self):
        """
        Test case for post_keywordsets

        Create a Keyword Set
        """
        pass

    def test_post_publishedforms(self):
        """
        Test case for post_publishedforms

        Publish an evaluation form.
        """
        pass

    def test_put_calibrations_calibration_id(self):
        """
        Test case for put_calibrations_calibration_id

        Update a calibration to the specified calibration via PUT.  Editable fields include: evaluators, expertEvaluator, and scoringIndex
        """
        pass

    def test_put_conversations_conversation_id_evaluations_evaluation_id(self):
        """
        Test case for put_conversations_conversation_id_evaluations_evaluation_id

        Update an evaluation
        """
        pass

    def test_put_forms_form_id(self):
        """
        Test case for put_forms_form_id

        Update an evaluation form.
        """
        pass

    def test_put_keywordsets_keywordset_id(self):
        """
        Test case for put_keywordsets_keywordset_id

        Update a keywordSet to the specified keywordSet via PUT.
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.conversations_api import ConversationsApi


class TestConversationsApi(unittest.TestCase):
    """ ConversationsApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.conversations_api.ConversationsApi()

    def tearDown(self):
        pass

    def test_delete_calls_call_id_participants_participant_id_consult(self):
        """
        Test case for delete_calls_call_id_participants_participant_id_consult

        Cancel the transfer
        """
        pass

    def test_delete_conversation_id_participants_participant_id_codes_addcommunicationcode(self):
        """
        Test case for delete_conversation_id_participants_participant_id_codes_addcommunicationcode

        Delete a code used to add a communication to this participant
        """
        pass

    def test_delete_emails_email_id_messages_draft_attachments_attachment_id(self):
        """
        Test case for delete_emails_email_id_messages_draft_attachments_attachment_id

        Delete attachment from draft
        """
        pass

    def test_get_callbacks(self):
        """
        Test case for get_callbacks

        Get callback conversations
        """
        pass

    def test_get_callbacks_callback_id(self):
        """
        Test case for get_callbacks_callback_id

        Get callback conversation
        """
        pass

    def test_get_callbacks_callback_id_participants_participant_id_wrapup(self):
        """
        Test case for get_callbacks_callback_id_participants_participant_id_wrapup

        Get the wrap-up for this conversation participant. 
        """
        pass

    def test_get_callbacks_callback_id_participants_participant_id_wrapupcodes(self):
        """
        Test case for get_callbacks_callback_id_participants_participant_id_wrapupcodes

        Get list of wrapup codes for this conversation participant
        """
        pass

    def test_get_calls(self):
        """
        Test case for get_calls

        Get recent conversations
        """
        pass

    def test_get_calls_call_id(self):
        """
        Test case for get_calls_call_id

        Get call conversation
        """
        pass

    def test_get_calls_call_id_participants_participant_id_wrapup(self):
        """
        Test case for get_calls_call_id_participants_participant_id_wrapup

        Get the wrap-up for this conversation participant. 
        """
        pass

    def test_get_calls_call_id_participants_participant_id_wrapupcodes(self):
        """
        Test case for get_calls_call_id_participants_participant_id_wrapupcodes

        Get list of wrapup codes for this conversation participant
        """
        pass

    def test_get_calls_history(self):
        """
        Test case for get_calls_history

        Get call history
        """
        pass

    def test_get_calls_maximumconferenceparties(self):
        """
        Test case for get_calls_maximumconferenceparties

        Get the maximum number of participants that this user can have on a conference
        """
        pass

    def test_get_chats(self):
        """
        Test case for get_chats

        Get recent chat conversations
        """
        pass

    def test_get_chats_chat_id(self):
        """
        Test case for get_chats_chat_id

        Get chat conversation
        """
        pass

    def test_get_chats_chat_id_participants_participant_id_wrapup(self):
        """
        Test case for get_chats_chat_id_participants_participant_id_wrapup

        Get the wrap-up for this conversation participant. 
        """
        pass

    def test_get_chats_chat_id_participants_participant_id_wrapupcodes(self):
        """
        Test case for get_chats_chat_id_participants_participant_id_wrapupcodes

        Get list of wrapup codes for this conversation participant
        """
        pass

    def test_get_conversation_id(self):
        """
        Test case for get_conversation_id

        Get conversation
        """
        pass

    def test_get_conversation_id_participants_participant_id_wrapup(self):
        """
        Test case for get_conversation_id_participants_participant_id_wrapup

        Get the wrap-up for this conversation participant. 
        """
        pass

    def test_get_conversation_id_participants_participant_id_wrapupcodes(self):
        """
        Test case for get_conversation_id_participants_participant_id_wrapupcodes

        Get list of wrapup codes for this conversation participant
        """
        pass

    def test_get_conversations(self):
        """
        Test case for get_conversations

        Get conversations
        """
        pass

    def test_get_conversations_conversation_id_details(self):
        """
        Test case for get_conversations_conversation_id_details

        Get a conversation by id
        """
        pass

    def test_get_emails(self):
        """
        Test case for get_emails

        Get recent email conversations
        """
        pass

    def test_get_emails_email_id(self):
        """
        Test case for get_emails_email_id

        Get email conversation
        """
        pass

    def test_get_emails_email_id_messages(self):
        """
        Test case for get_emails_email_id_messages

        Get conversation messages
        """
        pass

    def test_get_emails_email_id_messages_draft(self):
        """
        Test case for get_emails_email_id_messages_draft

        Get conversation draft reply
        """
        pass

    def test_get_emails_email_id_messages_message_id(self):
        """
        Test case for get_emails_email_id_messages_message_id

        Get conversation message
        """
        pass

    def test_get_emails_email_id_participants_participant_id_wrapup(self):
        """
        Test case for get_emails_email_id_participants_participant_id_wrapup

        Get the wrap-up for this conversation participant. 
        """
        pass

    def test_get_emails_email_id_participants_participant_id_wrapupcodes(self):
        """
        Test case for get_emails_email_id_participants_participant_id_wrapupcodes

        Get list of wrapup codes for this conversation participant
        """
        pass

    def test_patch_callbacks_callback_id(self):
        """
        Test case for patch_callbacks_callback_id

        Update a conversation by disconnecting all of the participants
        """
        pass

    def test_patch_callbacks_callback_id_participants_participant_id(self):
        """
        Test case for patch_callbacks_callback_id_participants_participant_id

        Update conversation participant
        """
        pass

    def test_patch_callbacks_callback_id_participants_participant_id_attributes(self):
        """
        Test case for patch_callbacks_callback_id_participants_participant_id_attributes

        Update the attributes on a conversation participant.
        """
        pass

    def test_patch_callbacks_callback_id_participants_participant_id_communications_communication_id(self):
        """
        Test case for patch_callbacks_callback_id_participants_participant_id_communications_communication_id

        Update conversation participant's communication by disconnecting it.
        """
        pass

    def test_patch_calls_call_id(self):
        """
        Test case for patch_calls_call_id

        Update a conversation by setting it's recording state or disconnecting all of the participants
        """
        pass

    def test_patch_calls_call_id_participants_participant_id(self):
        """
        Test case for patch_calls_call_id_participants_participant_id

        Update conversation participant
        """
        pass

    def test_patch_calls_call_id_participants_participant_id_attributes(self):
        """
        Test case for patch_calls_call_id_participants_participant_id_attributes

        Update the attributes on a conversation participant.
        """
        pass

    def test_patch_calls_call_id_participants_participant_id_communications_communication_id(self):
        """
        Test case for patch_calls_call_id_participants_participant_id_communications_communication_id

        Update conversation participant's communication by disconnecting it.
        """
        pass

    def test_patch_calls_call_id_participants_participant_id_consult(self):
        """
        Test case for patch_calls_call_id_participants_participant_id_consult

        Change who can speak
        """
        pass

    def test_patch_chats_chat_id(self):
        """
        Test case for patch_chats_chat_id

        Update a conversation by disconnecting all of the participants
        """
        pass

    def test_patch_chats_chat_id_participants_participant_id(self):
        """
        Test case for patch_chats_chat_id_participants_participant_id

        Update conversation participant
        """
        pass

    def test_patch_chats_chat_id_participants_participant_id_attributes(self):
        """
        Test case for patch_chats_chat_id_participants_participant_id_attributes

        Update the attributes on a conversation participant.
        """
        pass

    def test_patch_chats_chat_id_participants_participant_id_communications_communication_id(self):
        """
        Test case for patch_chats_chat_id_participants_participant_id_communications_communication_id

        Update conversation participant's communication by disconnecting it.
        """
        pass

    def test_patch_conversation_id_participants_participant_id(self):
        """
        Test case for patch_conversation_id_participants_participant_id

        Update a participant.
        """
        pass

    def test_patch_conversation_id_participants_participant_id_attributes(self):
        """
        Test case for patch_conversation_id_participants_participant_id_attributes

        Update the attributes on a conversation participant.
        """
        pass

    def test_patch_emails_email_id(self):
        """
        Test case for patch_emails_email_id

        Update a conversation by disconnecting all of the participants
        """
        pass

    def test_patch_emails_email_id_participants_participant_id(self):
        """
        Test case for patch_emails_email_id_participants_participant_id

        Update conversation participant
        """
        pass

    def test_patch_emails_email_id_participants_participant_id_attributes(self):
        """
        Test case for patch_emails_email_id_participants_participant_id_attributes

        Update the attributes on a conversation participant.
        """
        pass

    def test_post_callbacks(self):
        """
        Test case for post_callbacks

        Create a Callback
        """
        pass

    def test_post_callbacks_callback_id_participants_participant_id_replace(self):
        """
        Test case for post_callbacks_callback_id_participants_participant_id_replace

        Replace this participant with the specified user and/or address
        """
        pass

    def test_post_calls(self):
        """
        Test case for post_calls

        Create a call conversation
        """
        pass

    def test_post_calls_call_id(self):
        """
        Test case for post_calls_call_id

        Add a new call to a conversation
        """
        pass

    def test_post_calls_call_id_participants(self):
        """
        Test case for post_calls_call_id_participants

        Add participants to a conversation
        """
        pass

    def test_post_calls_call_id_participants_participant_id_consult(self):
        """
        Test case for post_calls_call_id_participants_participant_id_consult

        Initiate and update consult transfer
        """
        pass

    def test_post_calls_call_id_participants_participant_id_monitor(self):
        """
        Test case for post_calls_call_id_participants_participant_id_monitor

        Listen in on the conversation from the point of view of a given participant.
        """
        pass

    def test_post_calls_call_id_participants_participant_id_replace(self):
        """
        Test case for post_calls_call_id_participants_participant_id_replace

        Replace this participant with the specified user and/or address
        """
        pass

    def test_post_chats_chat_id_participants_participant_id_replace(self):
        """
        Test case for post_chats_chat_id_participants_participant_id_replace

        Replace this participant with the specified user and/or address
        """
        pass

    def test_post_conversation_id_participants_participant_id_callbacks(self):
        """
        Test case for post_conversation_id_participants_participant_id_callbacks

        Create a new callback for the specified participant on the conversation.
        """
        pass

    def test_post_conversation_id_participants_participant_id_replace(self):
        """
        Test case for post_conversation_id_participants_participant_id_replace

        Replace this participant with the specified user and/or address
        """
        pass

    def test_post_conversations_aggregates_query(self):
        """
        Test case for post_conversations_aggregates_query

        Query for conversation aggregates
        """
        pass

    def test_post_conversations_conversation_id_details_properties(self):
        """
        Test case for post_conversations_conversation_id_details_properties

        Index conversation properties
        """
        pass

    def test_post_conversations_details_query(self):
        """
        Test case for post_conversations_details_query

        Query for conversation details
        """
        pass

    def test_post_emails_email_id_messages(self):
        """
        Test case for post_emails_email_id_messages

        Send an email reply
        """
        pass

    def test_post_emails_email_id_participants_participant_id_replace(self):
        """
        Test case for post_emails_email_id_participants_participant_id_replace

        Replace this participant with the specified user and/or address
        """
        pass

    def test_post_faxes(self):
        """
        Test case for post_faxes

        Create Fax Conversation
        """
        pass

    def test_put_emails_email_id_messages_draft(self):
        """
        Test case for put_emails_email_id_messages_draft

        Update conversation draft reply
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class DocumentAudit(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DocumentAudit - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'user': 'UriReference',
            'workspace': 'UriReference',
            'transaction_id': 'str',
            'transaction_initiator': 'bool',
            'application': 'str',
            'service_name': 'str',
            'level': 'str',
            'timestamp': 'datetime',
            'status': 'str',
            'action_context': 'str',
            'action': 'str',
            'entity': 'AuditEntityReference',
            'changes': 'list[AuditChange]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'user': 'user',
            'workspace': 'workspace',
            'transaction_id': 'transactionId',
            'transaction_initiator': 'transactionInitiator',
            'application': 'application',
            'service_name': 'serviceName',
            'level': 'level',
            'timestamp': 'timestamp',
            'status': 'status',
            'action_context': 'actionContext',
            'action': 'action',
            'entity': 'entity',
            'changes': 'changes',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._user = None
        self._workspace = None
        self._transaction_id = None
        self._transaction_initiator = False
        self._application = None
        self._service_name = None
        self._level = None
        self._timestamp = None
        self._status = None
        self._action_context = None
        self._action = None
        self._entity = None
        self._changes = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this DocumentAudit.
        The globally unique identifier for the object.

        :return: The id of this DocumentAudit.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DocumentAudit.
        The globally unique identifier for the object.

        :param id: The id of this DocumentAudit.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DocumentAudit.


        :return: The name of this DocumentAudit.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DocumentAudit.


        :param name: The name of this DocumentAudit.
        :type: str
        """
        
        self._name = name

    @property
    def user(self):
        """
        Gets the user of this DocumentAudit.


        :return: The user of this DocumentAudit.
        :rtype: UriReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this DocumentAudit.


        :param user: The user of this DocumentAudit.
        :type: UriReference
        """
        
        self._user = user

    @property
    def workspace(self):
        """
        Gets the workspace of this DocumentAudit.


        :return: The workspace of this DocumentAudit.
        :rtype: UriReference
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """
        Sets the workspace of this DocumentAudit.


        :param workspace: The workspace of this DocumentAudit.
        :type: UriReference
        """
        
        self._workspace = workspace

    @property
    def transaction_id(self):
        """
        Gets the transaction_id of this DocumentAudit.


        :return: The transaction_id of this DocumentAudit.
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """
        Sets the transaction_id of this DocumentAudit.


        :param transaction_id: The transaction_id of this DocumentAudit.
        :type: str
        """
        
        self._transaction_id = transaction_id

    @property
    def transaction_initiator(self):
        """
        Gets the transaction_initiator of this DocumentAudit.


        :return: The transaction_initiator of this DocumentAudit.
        :rtype: bool
        """
        return self._transaction_initiator

    @transaction_initiator.setter
    def transaction_initiator(self, transaction_initiator):
        """
        Sets the transaction_initiator of this DocumentAudit.


        :param transaction_initiator: The transaction_initiator of this DocumentAudit.
        :type: bool
        """
        
        self._transaction_initiator = transaction_initiator

    @property
    def application(self):
        """
        Gets the application of this DocumentAudit.


        :return: The application of this DocumentAudit.
        :rtype: str
        """
        return self._application

    @application.setter
    def application(self, application):
        """
        Sets the application of this DocumentAudit.


        :param application: The application of this DocumentAudit.
        :type: str
        """
        
        self._application = application

    @property
    def service_name(self):
        """
        Gets the service_name of this DocumentAudit.


        :return: The service_name of this DocumentAudit.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this DocumentAudit.


        :param service_name: The service_name of this DocumentAudit.
        :type: str
        """
        
        self._service_name = service_name

    @property
    def level(self):
        """
        Gets the level of this DocumentAudit.


        :return: The level of this DocumentAudit.
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """
        Sets the level of this DocumentAudit.


        :param level: The level of this DocumentAudit.
        :type: str
        """
        allowed_values = ["USER", "SYSTEM"]
        if level not in allowed_values:
            raise ValueError(
                "Invalid value for `level`, must be one of {0}"
                .format(allowed_values)
            )

        self._level = level

    @property
    def timestamp(self):
        """
        Gets the timestamp of this DocumentAudit.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The timestamp of this DocumentAudit.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this DocumentAudit.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param timestamp: The timestamp of this DocumentAudit.
        :type: datetime
        """
        
        self._timestamp = timestamp

    @property
    def status(self):
        """
        Gets the status of this DocumentAudit.


        :return: The status of this DocumentAudit.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DocumentAudit.


        :param status: The status of this DocumentAudit.
        :type: str
        """
        allowed_values = ["SUCCESS", "FAILURE"]
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status`, must be one of {0}"
                .format(allowed_values)
            )

        self._status = status

    @property
    def action_context(self):
        """
        Gets the action_context of this DocumentAudit.


        :return: The action_context of this DocumentAudit.
        :rtype: str
        """
        return self._action_context

    @action_context.setter
    def action_context(self, action_context):
        """
        Sets the action_context of this DocumentAudit.


        :param action_context: The action_context of this DocumentAudit.
        :type: str
        """
        allowed_values = ["CREATE", "READ", "UPDATE", "DELETE", "DOWNLOAD", "VIEW", "UPLOAD", "SAVE", "MOVE", "COPY", "ADD", "REMOVE", "RECEIVE", "CONVERT", "FAX", "CREATE_COVERPAGE", "USER_ADD", "USER_REMOVE", "MEMBER_ADD", "MEMBER_REMOVE", "MEMBER_UPDATE", "TAG_ADD", "TAG_REMOVE", "TAG_UPDATE", "ATTRIBUTE_ADD", "ATTRIBUTE_REMOVE", "ATTRIBUTE_UPDATE", "ATTRIBUTE_GROUP_INSTANCE_ADD", "ATTRIBUTE_GROUP_INSTANCE_REMOVE", "ATTRIBUTE_GROUP_INSTANCE_UPDATE", "INDEX_SAVE", "INDEX_DELETE", "INDEX_CREATE", "FILE_SAVE", "FILE_DELETE", "FILE_READ", "THUMBNAIL_CREATE", "TEXT_EXTRACT", "SHARE_ADD", "SHARE_REMOVE", "VERSION_CREATE"]
        if action_context not in allowed_values:
            raise ValueError(
                "Invalid value for `action_context`, must be one of {0}"
                .format(allowed_values)
            )

        self._action_context = action_context

    @property
    def action(self):
        """
        Gets the action of this DocumentAudit.


        :return: The action of this DocumentAudit.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this DocumentAudit.


        :param action: The action of this DocumentAudit.
        :type: str
        """
        allowed_values = ["CREATE", "READ", "UPDATE", "DELETE", "DOWNLOAD", "VIEW", "UPLOAD", "SAVE", "MOVE", "COPY", "ADD", "REMOVE", "RECEIVE", "CONVERT", "FAX", "CREATE_COVERPAGE", "USER_ADD", "USER_REMOVE", "MEMBER_ADD", "MEMBER_REMOVE", "MEMBER_UPDATE", "TAG_ADD", "TAG_REMOVE", "TAG_UPDATE", "ATTRIBUTE_ADD", "ATTRIBUTE_REMOVE", "ATTRIBUTE_UPDATE", "ATTRIBUTE_GROUP_INSTANCE_ADD", "ATTRIBUTE_GROUP_INSTANCE_REMOVE", "ATTRIBUTE_GROUP_INSTANCE_UPDATE", "INDEX_SAVE", "INDEX_DELETE", "INDEX_CREATE", "FILE_SAVE", "FILE_DELETE", "FILE_READ", "THUMBNAIL_CREATE", "TEXT_EXTRACT", "SHARE_ADD", "SHARE_REMOVE", "VERSION_CREATE"]
        if action not in allowed_values:
            raise ValueError(
                "Invalid value for `action`, must be one of {0}"
                .format(allowed_values)
            )

        self._action = action

    @property
    def entity(self):
        """
        Gets the entity of this DocumentAudit.


        :return: The entity of this DocumentAudit.
        :rtype: AuditEntityReference
        """
        return self._entity

    @entity.setter
    def entity(self, entity):
        """
        Sets the entity of this DocumentAudit.


        :param entity: The entity of this DocumentAudit.
        :type: AuditEntityReference
        """
        
        self._entity = entity

    @property
    def changes(self):
        """
        Gets the changes of this DocumentAudit.


        :return: The changes of this DocumentAudit.
        :rtype: list[AuditChange]
        """
        return self._changes

    @changes.setter
    def changes(self, changes):
        """
        Sets the changes of this DocumentAudit.


        :param changes: The changes of this DocumentAudit.
        :type: list[AuditChange]
        """
        
        self._changes = changes

    @property
    def self_uri(self):
        """
        Gets the self_uri of this DocumentAudit.
        The URI for this object

        :return: The self_uri of this DocumentAudit.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this DocumentAudit.
        The URI for this object

        :param self_uri: The self_uri of this DocumentAudit.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class OrganizationPresence(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OrganizationPresence - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'language_labels': 'dict(str, str)',
            'system_presence': 'str',
            'deactivated': 'bool',
            'primary': 'bool',
            'created_by': 'User',
            'created_date': 'datetime',
            'modified_by': 'User',
            'modified_date': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'language_labels': 'languageLabels',
            'system_presence': 'systemPresence',
            'deactivated': 'deactivated',
            'primary': 'primary',
            'created_by': 'createdBy',
            'created_date': 'createdDate',
            'modified_by': 'modifiedBy',
            'modified_date': 'modifiedDate',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._language_labels = None
        self._system_presence = None
        self._deactivated = False
        self._primary = False
        self._created_by = None
        self._created_date = None
        self._modified_by = None
        self._modified_date = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this OrganizationPresence.
        The globally unique identifier for the object.

        :return: The id of this OrganizationPresence.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OrganizationPresence.
        The globally unique identifier for the object.

        :param id: The id of this OrganizationPresence.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this OrganizationPresence.


        :return: The name of this OrganizationPresence.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OrganizationPresence.


        :param name: The name of this OrganizationPresence.
        :type: str
        """
        
        self._name = name

    @property
    def language_labels(self):
        """
        Gets the language_labels of this OrganizationPresence.


        :return: The language_labels of this OrganizationPresence.
        :rtype: dict(str, str)
        """
        return self._language_labels

    @language_labels.setter
    def language_labels(self, language_labels):
        """
        Sets the language_labels of this OrganizationPresence.


        :param language_labels: The language_labels of this OrganizationPresence.
        :type: dict(str, str)
        """
        
        self._language_labels = language_labels

    @property
    def system_presence(self):
        """
        Gets the system_presence of this OrganizationPresence.


        :return: The system_presence of this OrganizationPresence.
        :rtype: str
        """
        return self._system_presence

    @system_presence.setter
    def system_presence(self, system_presence):
        """
        Sets the system_presence of this OrganizationPresence.


        :param system_presence: The system_presence of this OrganizationPresence.
        :type: str
        """
        
        self._system_presence = system_presence

    @property
    def deactivated(self):
        """
        Gets the deactivated of this OrganizationPresence.


        :return: The deactivated of this OrganizationPresence.
        :rtype: bool
        """
        return self._deactivated

    @deactivated.setter
    def deactivated(self, deactivated):
        """
        Sets the deactivated of this OrganizationPresence.


        :param deactivated: The deactivated of this OrganizationPresence.
        :type: bool
        """
        
        self._deactivated = deactivated

    @property
    def primary(self):
        """
        Gets the primary of this OrganizationPresence.


        :return: The primary of this OrganizationPresence.
        :rtype: bool
        """
        return self._primary

    @primary.setter
    def primary(self, primary):
        """
        Sets the primary of this OrganizationPresence.


        :param primary: The primary of this OrganizationPresence.
        :type: bool
        """
        
        self._primary = primary

    @property
    def created_by(self):
        """
        Gets the created_by of this OrganizationPresence.


        :return: The created_by of this OrganizationPresence.
        :rtype: User
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this OrganizationPresence.


        :param created_by: The created_by of this OrganizationPresence.
        :type: User
        """
        
        self._created_by = created_by

    @property
    def created_date(self):
        """
        Gets the created_date of this OrganizationPresence.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The created_date of this OrganizationPresence.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this OrganizationPresence.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param created_date: The created_date of this OrganizationPresence.
        :type: datetime
        """
        
        self._created_date = created_date

    @property
    def modified_by(self):
        """
        Gets the modified_by of this OrganizationPresence.


        :return: The modified_by of this OrganizationPresence.
        :rtype: User
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this OrganizationPresence.


        :param modified_by: The modified_by of this OrganizationPresence.
        :type: User
        """
        
        self._modified_by = modified_by

    @property
    def modified_date(self):
        """
        Gets the modified_date of this OrganizationPresence.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The modified_date of this OrganizationPresence.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this OrganizationPresence.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param modified_date: The modified_date of this OrganizationPresence.
        :type: datetime
        """
        
        self._modified_date = modified_date

    @property
    def self_uri(self):
        """
        Gets the self_uri of this OrganizationPresence.
        The URI for this object

        :return: The self_uri of this OrganizationPresence.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this OrganizationPresence.
        The URI for this object

        :param self_uri: The self_uri of this OrganizationPresence.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class StatisticalSummary(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        StatisticalSummary - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'max': 'float',
            'min': 'float',
            'count': 'int',
            'sum': 'float',
            'current': 'float',
            'ratio': 'float',
            'numerator': 'float',
            'denominator': 'float',
            'target': 'float'
        }

        self.attribute_map = {
            'max': 'max',
            'min': 'min',
            'count': 'count',
            'sum': 'sum',
            'current': 'current',
            'ratio': 'ratio',
            'numerator': 'numerator',
            'denominator': 'denominator',
            'target': 'target'
        }

        self._max = None
        self._min = None
        self._count = None
        self._sum = None
        self._current = None
        self._ratio = None
        self._numerator = None
        self._denominator = None
        self._target = None

    @property
    def max(self):
        """
        Gets the max of this StatisticalSummary.


        :return: The max of this StatisticalSummary.
        :rtype: float
        """
        return self._max

    @max.setter
    def max(self, max):
        """
        Sets the max of this StatisticalSummary.


        :param max: The max of this StatisticalSummary.
        :type: float
        """
        
        self._max = max

    @property
    def min(self):
        """
        Gets the min of this StatisticalSummary.


        :return: The min of this StatisticalSummary.
        :rtype: float
        """
        return self._min

    @min.setter
    def min(self, min):
        """
        Sets the min of this StatisticalSummary.


        :param min: The min of this StatisticalSummary.
        :type: float
        """
        
        self._min = min

    @property
    def count(self):
        """
        Gets the count of this StatisticalSummary.


        :return: The count of this StatisticalSummary.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this StatisticalSummary.


        :param count: The count of this StatisticalSummary.
        :type: int
        """
        
        self._count = count

    @property
    def sum(self):
        """
        Gets the sum of this StatisticalSummary.


        :return: The sum of this StatisticalSummary.
        :rtype: float
        """
        return self._sum

    @sum.setter
    def sum(self, sum):
        """
        Sets the sum of this StatisticalSummary.


        :param sum: The sum of this StatisticalSummary.
        :type: float
        """
        
        self._sum = sum

    @property
    def current(self):
        """
        Gets the current of this StatisticalSummary.


        :return: The current of this StatisticalSummary.
        :rtype: float
        """
        return self._current

    @current.setter
    def current(self, current):
        """
        Sets the current of this StatisticalSummary.


        :param current: The current of this StatisticalSummary.
        :type: float
        """
        
        self._current = current

    @property
    def ratio(self):
        """
        Gets the ratio of this StatisticalSummary.


        :return: The ratio of this StatisticalSummary.
        :rtype: float
        """
        return self._ratio

    @ratio.setter
    def ratio(self, ratio):
        """
        Sets the ratio of this StatisticalSummary.


        :param ratio: The ratio of this StatisticalSummary.
        :type: float
        """
        
        self._ratio = ratio

    @property
    def numerator(self):
        """
        Gets the numerator of this StatisticalSummary.


        :return: The numerator of this StatisticalSummary.
        :rtype: float
        """
        return self._numerator

    @numerator.setter
    def numerator(self, numerator):
        """
        Sets the numerator of this StatisticalSummary.


        :param numerator: The numerator of this StatisticalSummary.
        :type: float
        """
        
        self._numerator = numerator

    @property
    def denominator(self):
        """
        Gets the denominator of this StatisticalSummary.


        :return: The denominator of this StatisticalSummary.
        :rtype: float
        """
        return self._denominator

    @denominator.setter
    def denominator(self, denominator):
        """
        Sets the denominator of this StatisticalSummary.


        :param denominator: The denominator of this StatisticalSummary.
        :type: float
        """
        
        self._denominator = denominator

    @property
    def target(self):
        """
        Gets the target of this StatisticalSummary.


        :return: The target of this StatisticalSummary.
        :rtype: float
        """
        return self._target

    @target.setter
    def target(self, target):
        """
        Sets the target of this StatisticalSummary.


        :param target: The target of this StatisticalSummary.
        :type: float
        """
        
        self._target = target

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.attributes_api import AttributesApi


class TestAttributesApi(unittest.TestCase):
    """ AttributesApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.attributes_api.AttributesApi()

    def tearDown(self):
        pass

    def test_delete_attribute_id(self):
        """
        Test case for delete_attribute_id

        Delete an existing Attribute.
        """
        pass

    def test_get_attribute_id(self):
        """
        Test case for get_attribute_id

        Get details about an existing attribute.
        """
        pass

    def test_get_attributes(self):
        """
        Test case for get_attributes

        Gets a list of existing attributes.
        """
        pass

    def test_post_attributes(self):
        """
        Test case for post_attributes

        Create an attribute.
        """
        pass

    def test_post_query(self):
        """
        Test case for post_query

        Query attributes
        """
        pass

    def test_put_attribute_id(self):
        """
        Test case for put_attribute_id

        Update an existing attribute.
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class DurationCondition(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DurationCondition - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'duration_target': 'str',
            'duration_operator': 'str',
            'duration_range': 'str'
        }

        self.attribute_map = {
            'duration_target': 'durationTarget',
            'duration_operator': 'durationOperator',
            'duration_range': 'durationRange'
        }

        self._duration_target = None
        self._duration_operator = None
        self._duration_range = None

    @property
    def duration_target(self):
        """
        Gets the duration_target of this DurationCondition.


        :return: The duration_target of this DurationCondition.
        :rtype: str
        """
        return self._duration_target

    @duration_target.setter
    def duration_target(self, duration_target):
        """
        Sets the duration_target of this DurationCondition.


        :param duration_target: The duration_target of this DurationCondition.
        :type: str
        """
        allowed_values = ["DURATION", "DURATION_RANGE"]
        if duration_target not in allowed_values:
            raise ValueError(
                "Invalid value for `duration_target`, must be one of {0}"
                .format(allowed_values)
            )

        self._duration_target = duration_target

    @property
    def duration_operator(self):
        """
        Gets the duration_operator of this DurationCondition.


        :return: The duration_operator of this DurationCondition.
        :rtype: str
        """
        return self._duration_operator

    @duration_operator.setter
    def duration_operator(self, duration_operator):
        """
        Sets the duration_operator of this DurationCondition.


        :param duration_operator: The duration_operator of this DurationCondition.
        :type: str
        """
        
        self._duration_operator = duration_operator

    @property
    def duration_range(self):
        """
        Gets the duration_range of this DurationCondition.


        :return: The duration_range of this DurationCondition.
        :rtype: str
        """
        return self._duration_range

    @duration_range.setter
    def duration_range(self, duration_range):
        """
        Sets the duration_range of this DurationCondition.


        :param duration_range: The duration_range of this DurationCondition.
        :type: str
        """
        
        self._duration_range = duration_range

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class KeywordSet(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        KeywordSet - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'queue': 'Queue',
            'queues': 'list[Queue]',
            'language': 'str',
            'agents': 'list[User]',
            'keywords': 'list[Keyword]',
            'participant_purposes': 'list[str]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'queue': 'queue',
            'queues': 'queues',
            'language': 'language',
            'agents': 'agents',
            'keywords': 'keywords',
            'participant_purposes': 'participantPurposes',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._queue = None
        self._queues = None
        self._language = None
        self._agents = None
        self._keywords = None
        self._participant_purposes = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this KeywordSet.
        The globally unique identifier for the object.

        :return: The id of this KeywordSet.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this KeywordSet.
        The globally unique identifier for the object.

        :param id: The id of this KeywordSet.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this KeywordSet.


        :return: The name of this KeywordSet.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this KeywordSet.


        :param name: The name of this KeywordSet.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this KeywordSet.


        :return: The description of this KeywordSet.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this KeywordSet.


        :param description: The description of this KeywordSet.
        :type: str
        """
        
        self._description = description

    @property
    def queue(self):
        """
        Gets the queue of this KeywordSet.


        :return: The queue of this KeywordSet.
        :rtype: Queue
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this KeywordSet.


        :param queue: The queue of this KeywordSet.
        :type: Queue
        """
        
        self._queue = queue

    @property
    def queues(self):
        """
        Gets the queues of this KeywordSet.


        :return: The queues of this KeywordSet.
        :rtype: list[Queue]
        """
        return self._queues

    @queues.setter
    def queues(self, queues):
        """
        Sets the queues of this KeywordSet.


        :param queues: The queues of this KeywordSet.
        :type: list[Queue]
        """
        
        self._queues = queues

    @property
    def language(self):
        """
        Gets the language of this KeywordSet.


        :return: The language of this KeywordSet.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this KeywordSet.


        :param language: The language of this KeywordSet.
        :type: str
        """
        
        self._language = language

    @property
    def agents(self):
        """
        Gets the agents of this KeywordSet.


        :return: The agents of this KeywordSet.
        :rtype: list[User]
        """
        return self._agents

    @agents.setter
    def agents(self, agents):
        """
        Sets the agents of this KeywordSet.


        :param agents: The agents of this KeywordSet.
        :type: list[User]
        """
        
        self._agents = agents

    @property
    def keywords(self):
        """
        Gets the keywords of this KeywordSet.


        :return: The keywords of this KeywordSet.
        :rtype: list[Keyword]
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """
        Sets the keywords of this KeywordSet.


        :param keywords: The keywords of this KeywordSet.
        :type: list[Keyword]
        """
        
        self._keywords = keywords

    @property
    def participant_purposes(self):
        """
        Gets the participant_purposes of this KeywordSet.


        :return: The participant_purposes of this KeywordSet.
        :rtype: list[str]
        """
        return self._participant_purposes

    @participant_purposes.setter
    def participant_purposes(self, participant_purposes):
        """
        Sets the participant_purposes of this KeywordSet.


        :param participant_purposes: The participant_purposes of this KeywordSet.
        :type: list[str]
        """
        
        self._participant_purposes = participant_purposes

    @property
    def self_uri(self):
        """
        Gets the self_uri of this KeywordSet.
        The URI for this object

        :return: The self_uri of this KeywordSet.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this KeywordSet.
        The URI for this object

        :param self_uri: The self_uri of this KeywordSet.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Contact(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Contact - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'address': 'str',
            'display': 'str',
            'media_type': 'str',
            'type': 'str'
        }

        self.attribute_map = {
            'address': 'address',
            'display': 'display',
            'media_type': 'mediaType',
            'type': 'type'
        }

        self._address = None
        self._display = None
        self._media_type = None
        self._type = None

    @property
    def address(self):
        """
        Gets the address of this Contact.
        Email address or phone number for this contact type

        :return: The address of this Contact.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this Contact.
        Email address or phone number for this contact type

        :param address: The address of this Contact.
        :type: str
        """
        
        self._address = address

    @property
    def display(self):
        """
        Gets the display of this Contact.
        Formatted version of the address property

        :return: The display of this Contact.
        :rtype: str
        """
        return self._display

    @display.setter
    def display(self, display):
        """
        Sets the display of this Contact.
        Formatted version of the address property

        :param display: The display of this Contact.
        :type: str
        """
        
        self._display = display

    @property
    def media_type(self):
        """
        Gets the media_type of this Contact.


        :return: The media_type of this Contact.
        :rtype: str
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """
        Sets the media_type of this Contact.


        :param media_type: The media_type of this Contact.
        :type: str
        """
        allowed_values = ["PHONE", "EMAIL", "SMS"]
        if media_type not in allowed_values:
            raise ValueError(
                "Invalid value for `media_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._media_type = media_type

    @property
    def type(self):
        """
        Gets the type of this Contact.


        :return: The type of this Contact.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Contact.


        :param type: The type of this Contact.
        :type: str
        """
        allowed_values = ["PRIMARY", "WORK", "WORK2", "WORK3", "WORK4", "HOME", "MOBILE", "MAIN"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.o_auth_api import OAuthApi


class TestOAuthApi(unittest.TestCase):
    """ OAuthApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.o_auth_api.OAuthApi()

    def tearDown(self):
        pass

    def test_delete_clients_client_id(self):
        """
        Test case for delete_clients_client_id

        Delete OAuth Client
        """
        pass

    def test_get_clients(self):
        """
        Test case for get_clients

        The list of OAuth clients
        """
        pass

    def test_get_clients_client_id(self):
        """
        Test case for get_clients_client_id

        Get OAuth Client
        """
        pass

    def test_post_clients(self):
        """
        Test case for post_clients

        Create OAuth client
        """
        pass

    def test_post_clients_client_id_secret(self):
        """
        Test case for post_clients_client_id_secret

        Regenerate Client Secret
        """
        pass

    def test_put_clients_client_id(self):
        """
        Test case for put_clients_client_id

        Update OAuth Client
        """
        pass


if __name__ == '__main__':
    unittest.main()